import * as React from 'react';
import { ModalProps, ModalFuncProps } from 'antd/lib/modal/Modal';
export interface SelectWrapperProps {
    /**
    * 可供选择样式，默认是checkbox
    */
    type?: 'checkbox' | 'list' | 'tag' | 'tree';
    /**
     * 搜索类型，默认是show在搜索框下面一排展示，filter表示过滤数据
     */
    searchType?: 'filter' | 'show';
    /**
     * 多选还是单选，默认true多选
     */
    multy?: boolean;
    /**
    * 是否全部展开，默认true展开
    */
    defaultExpandAll?: boolean;
    /**
     * 默认展开指定的树节点
     */
    defaultExpandedKeys?: string[];
    /**
     * 传入的所有可供选择的对象数组
     */
    options?: {
        name?: string;
        value?: any;
        [key: string]: any;
    }[];
    /**
     * 规类，传入后 options将根据field字段归类，根据render转义
     */
    classify?: {
        field: string;
        render?: Function;
        other?: string;
    };
    /**
     * 传入对象的业务展示名称，如警种、岗位等
     */
    typeName?: string;
    /**
     * 默认传入的由[valueField]字段组成的字符串或列表，字符串用逗号隔开，默认为空
     */
    data?: string | string[] | number[];
    /**
     * 名称字段,默认name
     */
    nameField?: string;
    /**
     * 值字段,默认value
     */
    valueField?: string;
    /**
     * 对象展示转换
     */
    renderItem?: (item?: any, i?: any) => React.ReactNode;
    /**
     * 列数，默认无，仅对 checkbox和tag生效
     */
    span?: number;
    /**
     * 构造类似于省-市的二级过滤列表
     */
    super?: {
        /**
         * 一级分组对象数组,nameField和valueField和外层相同
         */
        options: {
            name?: string;
            value?: any;
            [key: string]: any;
        }[];
        /**
         * 传入对象的业务展示名称，如警种、岗位等
         */
        typeName?: string;
        /**
         * 二级对象上的字段，用于关联上级
         */
        subField: string;
        /**
         * 对象展示转换
         */
        renderItem?: (item?: any, i?: any) => React.ReactNode;
    };
    /**
     * type为tag|checkbox|list时，在线获取数据，返回的数据合并options, param里面count_默认为99999，post请求时出现分页
     */
    query?: {
        /**
         * 获取数据的方法，默认get
         */
        method?: 'get' | 'post';
        /**
         * 获取数据的接口
         */
        api: string;
        /**
         * 获取数据的参数
         */
        param?: object;
    };
    /**
     * type为tree时在线构造树，若不传则表示采用options构造静态树
     */
    queryTree?: {
        /**
         * 获取根节点或全部数据的方法，GET请求
         */
        rootApi?: string;
        /**
         * 获取动态树节点的方法，GET请求
         */
        leafApi?: string;
        /**
         * 传函数时表示在线动态树表示当前节点是否为叶子节点，传string时表示在线静态树里父节点取值字段，如parentCode
         */
        isLeaf?: string | ((item: any) => boolean);
        /**
         * 静态树根节点值，默认为''
         */
        rootValue?: string | number | null;
    };
    /**
     * 选中事件
     */
    onChange?: any;
    /**
     * other
     */
    [propName: string]: any;
}
export interface SelectModalProps extends SelectWrapperProps, ModalProps {
    onOk?: any;
}
export interface SelectModalFuncProps extends SelectWrapperProps, Omit<ModalFuncProps, 'type'> {
    onOk?: any;
}
/**
 * 多数据选择弹窗，少数据可用Select、Checkbox、Radio等
 * 可用于构造 Tag | Checkbox | List | 动态静态Tree | 左右二级联动List 等展示格式，提供页面搜索功能
 */
export declare class SelectWrapper extends React.PureComponent<SelectWrapperProps> {
    state: {
        options: any[];
        filterOptions: any[];
        inputValue: string;
        selectKeys: any[];
        allChecked: boolean;
        isExpand: boolean;
        subAllChecked: boolean;
        subClick: string;
        count_: number;
        start_: number;
        total: number;
    };
    optionsMap: Map<any, any>;
    nameField: string;
    valueField: string;
    typeName: string;
    superOptions: any[];
    superSubField: string;
    superTypeName: string;
    multy: boolean;
    defaultExpandAll: boolean;
    defaultExpandedKeys: any[];
    rootApi: string;
    leafApi: string;
    isLeaf: string;
    rootValue: string;
    treeOptions: any[];
    componentDidMount(): void;
    componentDidUpdate(old: any, oldState: any): void;
    change: () => void;
    init: () => void;
    setOptions: (data?: any) => Promise<void>;
    getData: () => Promise<any>;
    loadTreeData: (node: any) => Promise<any>;
    getTreeData: (code?: any) => Promise<any[]>;
    hasCheck: (value: any) => boolean;
    onSearchCheck: (e: any) => void;
    onAllSelectClick: (isAll: any) => void;
    onInvertSelect: () => void;
    onSearchClick: (item: any) => void;
    onItemClose: (item: any) => void;
    onItemDelete: () => void;
    onListSelect: (item: any) => void;
    onTagSelect: (checked: any, item: any) => void;
    onCheckboxSelect: (keys: any, allFilterKeys: any) => void;
    onSubCheck: (e: any, subOptions: any) => void;
    onTreeSelect: (selectKeys: any) => void;
    renderHasSelect: () => JSX.Element;
    renderList: (opts?: any[]) => JSX.Element;
    renderTag: (opts: any) => JSX.Element;
    renderCheckbox: (opts: any) => JSX.Element;
    renderDynamicTree: (opts: any) => JSX.Element;
    renderStaticTree: (opts: any) => JSX.Element;
    renderSuperFilter: () => JSX.Element;
    renderPagination: () => JSX.Element;
    render(): JSX.Element;
}
declare class SelectModal extends React.PureComponent<SelectModalProps> {
    state: {
        selectKeys: any[];
        names: any[];
    };
    static SHOW: (config: SelectModalFuncProps) => void;
    render(): JSX.Element;
}
export default SelectModal;
