import { TreeProps } from 'antd/lib/tree/Tree';
interface Result {
    code: string;
    message: string;
}
/**
 * 动态Tree 使用说明
 */
export interface DynamicTreeOpts extends TreeProps {
    /**
     * 获取 根节点的 api 或者传回调方法， 或者直接传一个数组
     */
    root: string;
    /**
     * 获取 子节点的 api 或者传回调方法
     * 如果传的是API接口，规范是 GET {api接口}/{key=parentId}
     */
    child: string;
    /**
     * 用于拼到 child 接口后面的字串
    */
    childSuffix?: string;
    /**
     * 选中一个节点时触发的方法
     */
    onSelect: (node: any, parent?: any) => void;
    /**
     * 至少选中一条才激活按钮，默认为false
     */
    mustSelect?: boolean;
    /**
     * 增删改查的API,需要符合 vap 接口规范
     */
    api?: string | ((data: any) => Promise<Result>);
    /**
     * 唯一键字段 ，默认为 id
     */
    keyField?: string;
    /**
     * 显示名称字段，默认为 name
     */
    nameField?: string;
    /**
     *  有 Icon 时，显示的字段
     */
    iconField?: string;
    /**
     * 父节点字段 ，默认为 parentId
     */
    parentField?: string;
    /**
     * 检查是否存在子节点，传字段名称，默认不检查
     * 字段的值必须 为 javascript 能判断的类型
    */
    checkChild?: string;
    mode?: 'search' | 'default';
}
export {};
