export type SystemConfApi = {
    api?: string;
    codeField?: string;
    valueField?: string;
    timeout?: number;
};
export interface GlobalSetting {
    /**
    * @deprecated
    * 统一使用 PAGINATION
    */
    PAGE_OPTIONS?: string[];
    /**
    * @deprecated
    * 统一使用 PAGINATION
    */
    PAGE_SIZE_DEFAULT?: number;
    /**
     * 接口规范 通用接口字段   code='code' message = 'message' success='0'
    */
    RESULT?: {
        code?: string;
        message?: string;
        success?: string;
    };
    /**
     * 接口规范 通用表格查询及返回
     * 请求 ： start='start_' count='count_' order='order_' by='by_'
     * 响应 ： list='list' total = 'total' totalAcc='totalAcc'
    */
    VLIST?: {
        list?: string;
        total?: string;
        totalAcc?: string;
        start?: string;
        count?: string;
        order?: string;
        by?: string;
    };
    /**
     * 接口规范 通用数据返回
     * 响应 ： data='data'
    */
    VDATA?: {
        data?: string;
    };
    /**
     * 字典配置
    */
    DICT_INFO?: {
        api?: string;
        codeField?: string;
        valueField?: string;
        idField?: string;
        parentField?: string;
    };
    /**
     * Ajax 配置
    */
    AJAX?: {
        /**
         * 全局超时时间
        */
        timeout?: number;
        /**
         * AOP 切点，发送前
        */
        beforeSend?: (url: string, method: string, header: any, param: any) => [string, string, any, any];
        /**
         * AOP 切点，响应前
         * 响应前的处理，说明：不支持 GETASYNC 、POSTASYNC 等请求
         *
         * 说明： 响应时 可以返回 true/false
         * 例如 :
         * ```typescript
         * beforeResive:(response: Response) => {
         *      if(response.status == 200){
         *          return true;
         *      }
         *      window.location.href = '/login/';
         *      return false;
         * }
         * ```
         *
         * 也可以返回  Promise<false | any>
         * 说明：非false 时，必须返回响应结果
         * 例如：
         * ```typescript
         * beforeResive: async (response:Response) => {
         *      const result = await response.json();
         *      if(result.code=='999999999'){
         *          window.location.href = '/login/';
         *          return false;
         *      }
         *      return result;
         * }
         * ```
        */
        beforeReceive?: (response: Response) => boolean | Promise<false | object>;
        /**
         * 通用请求头
        */
        globalHeader?: () => HeadersInit;
    };
    /**
     * 模态框
     * */
    MODAL?: {
        /**
        * @deprecated
         * 点击模态框外的遮罩层可关闭，
         * 已过期，现只支持 UFORM.maskClosable， 仅在 UFormMomdal / UModal 中生效
         * */
        maskClosable?: boolean;
    };
    UFORM?: {
        /**
         * 点击模态框外的遮罩层可关闭
         * */
        maskClosable?: boolean;
        /**
         * 所有输入框，自动加一条：不允许输入特殊字符，默认为 false
        */
        INPUT_SPECIAL_CHARACTER?: boolean;
        /**
         * 所有输入框，自动加一条：不允许输入特殊字符，
         * 默认为 36,
         * 可以通过设为0 取消限制
         * 也可以设置其它数字调整限制值
        */
        INPUT_MAX_LENGTH?: number;
    };
    /**
     * 全局表格设置
    */
    TABLE?: {
        /**
         * 全局忽略查询的 keyword_ ，默认不忽略
        */
        IGNORE_KEYWORD?: boolean;
        /**
         * 为true 时，按钮在左，输入在右
        */
        LAYOUT_REVERSE?: boolean;
    };
    /**
     * 提示文案
    */
    TIPS?: {
        ADD?: string;
        ADD_SUCCESS?: string;
        ADD_ERROR?: string;
        UPDATE?: string;
        UPDATE_SUCCESS?: string;
        UPDATE_ERROR?: string;
        DELETE?: string;
        DELETE_MULTI?: string;
        RENDER_TEXT?: string | false;
    };
    /**
     * 分页
    */
    PAGINATION?: {
        /**
         * 皮肤目前支持 3 套，传序号即可
        */
        THEME?: 1 | 2 | 3;
        OPTIONS?: string[];
        SIZE_DEFAULT?: number;
        SIZE_DEFAULT_MODAL?: number;
    };
}
declare global {
    interface VAP {
        cache: (key: string, val?: any) => void | any;
    }
    interface Window {
        antd: any;
        app: {
            unmodel: (namespace: string) => void;
            model: (ModelDefine: any) => void;
            _models: any[];
        };
        cache: (key: string, val?: any) => void | any;
        components: any;
        registerComponents: (...components: {
            path: string;
            component: any;
            like?: boolean;
        }[]) => void;
        registerNodes: (...nodes: any[]) => void;
        VAP_GLOBAL: GlobalSetting;
    }
}
