export default abstract class {
    /**
     * 字符串截取，把字符串按最大长度进行截取
     * @param txt 需要截取的字符串
     * @param len 最大长度，默认为20
     * @param hasDot 超长后是否以 `...` 进行结尾，默认为 `true`
     *
    */
    static formatString(str: string, len?: number, hasDot?: boolean): string;
    /**
        * @param number 一个数字
        * @return 格式化后的字符串
        * @description 格式化为美国数字显示方式（三位分开）
        ```javascript
        Format.formatUSD(123); 			//123
        Format.formatUSD(1234); 			//1,234
        Format.formatUSD(12345); 			//12,345
        Format.formatUSD(123456); 		//123,456
        Format.formatUSD(1234567); 		//1,234,567
        Format.formatUSD(1234567890); 	//1,234,567,890
    ```
        */
    static formatUSD: (n: number | {
        valueOf(): number;
    }) => string;
    /**
    * @param number 一个数字
    * @return 格式化后的字符串
    * @description 格式化后保留两位小数
    ```javascript
    Format.formatDecimal(1.234); 			//1.23
    Format.formatDecimal(1.236); 			//1,24
    Format.formatDecimal(1.2); 			//1.2
    Format.formatDecimal(1); 				//1
    ```
    */
    static formatDecimal: (number: string | number, limit?: number) => number;
    static formatNumber: (number: any) => number;
    /**
    * @param  number 一个数字
    * @return  格式化后的字符串
    * @description 将数字格式化为带中文单位,保留两位小数，支持`万`,`亿`
    ```javascript
    PageUtil.formatNumber(123); 			//123
    PageUtil.formatNumber(100000); 			//10万
    PageUtil.formatNumber(111111); 			//11.11万
    PageUtil.formatNumber(123456789); 		//1.23亿
    ```
    */
    static formatChinese(number: number): string | number;
    /**
    * @param  number 一个数字，单位为Byte(字节)
    * @return  格式化后的字符串
    * @description 格式化容量大小,保留两位小数，支持 `B`,`KB`,`MB`,`GB`,`TB`,`PB`
    ```javascript
    PageUtil.formatSize(123); 			//123MB
    PageUtil.formatSize(1024); 			//1GB
    PageUtil.formatSize(2050); 			//2.01GB
    ```
    */
    static formatSize(byteSize: number): string;
    static formatDate(date: string | Date, format?: string): string;
    /**
     * 格式化字符串，默认格式化为
     * aa***bb
     * @param value 被格式化字符串
     * @param beginNum 开始的字符数
     * @param endNum 结束的字符数
     */
    static formatStarStr(value: string, beginNum?: number, endNum?: number): string;
}
