import * as React from 'react';
import { ECharts } from 'echarts';
/**
 * Echarts组件属性
*/
export interface EchartProps {
    /**
     * class 属性
    */
    className?: string;
    /**
     * Echart数据
    */
    data: any;
    /**
     * Echart点击事件 参考 https://www.echartsjs.com/api.html#echartsInstance.on
     */
    onClick?: Function;
    /**
     * Echart点击事件 参考 https://www.echartsjs.com/api.html#echartsInstance.on
     */
    onClickType?: string;
    /**
     * 主题
     */
    theme?: string;
}
/**
 * 定义 echart 的规范
*/
export default abstract class extends React.PureComponent<EchartProps> {
    id: string;
    WIDTH: number;
    HEIGHT: number;
    DATA: any;
    chart: ECharts;
    abstract build(): any;
    abstract update(): any;
    _needResize(): boolean;
    /**
     * resize方法会在宽高发生变化的情况下自动调用
    */
    resize(): void;
    /**
     * init 方法会在build前自动调用
    */
    init(): void;
    /**
     * sort方法会在 build前 或 update前 自动调用
    */
    sort(): void;
    componentDidMount(): void;
    componentDidUpdate(): void;
    render(): JSX.Element;
}
export declare const registerTheme: (type: any, json: any) => void;
